/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include <stdlib.h>

#include "PerfectUsbPVCamDriver.h"
#include "UsbPVCamDriver.h"
#include "UsbPVCamDef.h"

namespace usbpvcam {

/*
 * Constructor
 */
PerfectUsbPVCamDriver::PerfectUsbPVCamDriver(UsbPVCamDriver* owner) :
		UsbPVCamState(owner) {
	/* Empty */
}

/*
 * Destructor
 */
PerfectUsbPVCamDriver::~PerfectUsbPVCamDriver() {
	/* Empty */
}

void PerfectUsbPVCamDriver::init() {
}

/*
 * clearvme/daugther/UsbPVCam
 */
void PerfectUsbPVCamDriver::clear() {
	// Read command
	owner()->time = 0;
	owner()->counts = 0;
	owner()->counts2 = 0;
	owner()->counts3 = 0;
}

/*
 * writeParam
 */
void PerfectUsbPVCamDriver::writeParam() {
}

/*
 * synchroniseRead
 */
void PerfectUsbPVCamDriver::synchroniseRead() {
	read();
	owner()->m_SynchroniseReadTerminated = true;
}

/*
 * read
 */
void PerfectUsbPVCamDriver::read() {
	// Read command
	int32 size = owner()->dataSize();

	int32 *tab = owner()->data();

	int32 sum = 0;
	//  if (m_FirstRead) {
	//    for (uint32 i=0;i<size;i++) {
	//      tab[i] = i + 1;
	//      sum = sum + tab[i];
	//    }
	//    m_FirstRead = false;
	//  } else {
	//    for (uint32 i=0;i<size;i++) {
	//      tab[i] = tab[i] + 1;
	//      sum = sum + tab[i];
	//    }
	//  }
	for (int32 i = 0; i < size; i++) {
		tab[i] = i;
		sum = sum + tab[i];
	}
	owner()->sum = sum;
	owner()->data.sendEvent();
}

/*
 * pause 
 */
void PerfectUsbPVCamDriver::pause() {
}

/*
 * continue 
 */
void PerfectUsbPVCamDriver::resume() {
}

/*
 * start
 */
void PerfectUsbPVCamDriver::start() {
	owner()->time = owner()->time.setpoint();
}

/*
 * stop
 */
void PerfectUsbPVCamDriver::stop() {
}

/*
 * readStatus
 */
void PerfectUsbPVCamDriver::readStatus() {
	owner()->startActivated = false;
	// Status command
	owner()->computeGateStatus(pvcam::READOUT_COMPLETE);
	owner()->computeAcquisitionStatus(0);
	owner()->computeDetectorStatus(0);
	if (owner()->m_SynchroniseReadActivated == true) {
		if (owner()->m_SynchroniseReadTerminated == true) {
			owner()->m_SynchroniseReadActivated = false;
			owner()->m_SynchroniseReadTerminated = false;
			owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
		}
	} else {
		owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
	}
}

/*
 * readInfos
 */
void PerfectUsbPVCamDriver::readInfos() {
}

}
